# openap-pypi-framework
This is a sample Python project designed to build and deploy a Python package.

# Install Homebrew

# Install and configure pyenv

# Insatll and configure python

# Create virtual environment
pyenv virtualenv 3.11.8 openap-pypi-framework

# Activate virtual environment
pyenv activate openap-pypi-framework

# Upgrade pip
python -m pip install --upgrade pip

# Install poetry
pip install poetry

# Create pyproject.toml file

# Install python packages using poetry

# pre-commit setup
